# bibframe.plugin

from bibframe.plugin import linkreport
from bibframe import register_service

register_service(linkreport.PLUGIN_INFO)
